@@ -35,9 +35,10 @@
 #include "gui_utils.h"
 #include "options_prefs.h"
 #include "calendar_notes.h"
-#include "calendar_utils.h"
 #include "calendar_timeline.h"
 #include "calendar_calc.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "calendar_moon.h"
 #include "stock_icons.h"
 
@@ -135,6 +136,90 @@ gchar *text;
 
 /*------------------------------------------------------------------------------*/
 
+void
+update_aux_calendars (GUI *appGUI) {
+
+gchar buffer[BUFFER_SIZE];
+GDate *cdate = NULL;
+gint prev_month, prev_year;
+gint next_month, next_year;
+gint i;
+
+    if (appGUI->calendar_only == TRUE || config.enable_auxilary_calendars == FALSE || config.auxilary_calendars_state == FALSE) {
+        return;
+    }
+
+    cdate = g_date_new();
+
+    if (cdate != NULL) {
+
+        prev_month = appGUI->cal->month - 1;
+        next_month = appGUI->cal->month + 1;
+        prev_year = next_year = appGUI->cal->year;
+
+        if (prev_month == -1) {
+            prev_month = 11;
+            prev_year--;
+        }
+
+        if (next_month == 12) {
+            next_month = 0;
+            next_year++;
+        } 
+
+        g_date_set_day (cdate, 1);
+        g_date_set_year (cdate, prev_year);
+        g_date_set_month (cdate, prev_month+1);
+        g_date_strftime (buffer, BUFFER_SIZE-1, "%B %Y", cdate);
+
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->prev_month_label), buffer);
+
+        g_date_set_day (cdate, 1);
+        g_date_set_year (cdate, next_year);
+        g_date_set_month (cdate, next_month+1);
+        g_date_strftime (buffer, BUFFER_SIZE-1, "%B %Y", cdate);
+
+        gtk_label_set_text (GTK_LABEL(appGUI->cal->next_month_label), buffer);
+
+        gui_calendar_select_month (GUI_CALENDAR (appGUI->cal->calendar_prev), prev_month, prev_year);
+        gui_calendar_select_month (GUI_CALENDAR (appGUI->cal->calendar_next), next_month, next_year);
+        gui_calendar_select_day (GUI_CALENDAR (appGUI->cal->calendar_prev), 1);
+        gui_calendar_select_day (GUI_CALENDAR (appGUI->cal->calendar_next), 1);
+        gui_calendar_clear_marks (GUI_CALENDAR(appGUI->cal->calendar_prev));
+        gui_calendar_clear_marks (GUI_CALENDAR(appGUI->cal->calendar_next));
+        gui_calendar_tc_clear_marks (GUI_CALENDAR(appGUI->cal->calendar_prev));
+        gui_calendar_tc_clear_marks (GUI_CALENDAR(appGUI->cal->calendar_next));
+
+        for (i = 1; i <= 31; i++) {
+
+            /* prev month */
+            if (i <= get_number_of_days_in_month(prev_month, prev_year)) {
+                if (check_note(i, prev_month+1, prev_year, appGUI) == TRUE) {
+                    gui_calendar_mark_day_color (GUI_CALENDAR(appGUI->cal->calendar_prev), 
+                                                 i, get_color(i, prev_month+1, prev_year, appGUI));
+                }
+                if (check_tasks_contacts(i, prev_month, prev_year, appGUI) == TRUE) {
+                    gui_calendar_tc_mark_day (GUI_CALENDAR(appGUI->cal->calendar_prev), i);
+                }
+            }
+
+            /* next month */
+            if (i <= get_number_of_days_in_month(next_month, next_year)) {
+                if (check_note(i, next_month+1, next_year, appGUI) == TRUE) {
+                    gui_calendar_mark_day_color (GUI_CALENDAR(appGUI->cal->calendar_next), 
+                                                 i, get_color(i, next_month+1, next_year, appGUI));
+                }
+                if (check_tasks_contacts(i, next_month, next_year, appGUI) == TRUE) {
+                    gui_calendar_tc_mark_day (GUI_CALENDAR(appGUI->cal->calendar_next), i);
+                }
+            }
+
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 gint
 check_add_tasks(guint32 selected_julian, gboolean count, GUI *appGUI) {
 
@@ -286,20 +371,45 @@ gint i;
 /*------------------------------------------------------------------------------*/
 
 gboolean
-check_tasks_contacts(guint tc_day, guint tc_month, guint tc_year, GUI *appGUI) {
+check_tasks (guint tc_day, guint tc_month, guint tc_year, GUI *appGUI) {
 
 GtkTreePath *path;
 GtkTreeIter iter;
-guint32 date, age, selected_julian;
-GDate *new_cdate;
-
-    if (appGUI->calendar_only == TRUE || appGUI->all_pages_added == FALSE) {
-        return FALSE;
-    }
+guint32 date, selected_julian;
 
     selected_julian = date_to_julian (tc_day, tc_month, tc_year);
 
-    /* check contacts */
+    if (appGUI->tsk->tasks_list_store != NULL) {
+        path = gtk_tree_path_new_first();
+
+        while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path) == TRUE) {
+            gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
+                                COLUMN_DUE_DATE_JULIAN, &date, -1);
+
+            if (date == selected_julian) {
+                return TRUE;
+            }
+
+            gtk_tree_path_next(path);
+        }
+        gtk_tree_path_free(path);
+
+    }
+
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+gboolean
+check_contacts (guint tc_day, guint tc_month, guint tc_year, GUI *appGUI) {
+
+GtkTreePath *path;
+GtkTreeIter iter;
+GDate *new_cdate;
+guint32 date, age, selected_julian;
+
+    selected_julian = date_to_julian (tc_day, tc_month, tc_year);
 
     if (appGUI->cnt->contacts_list_store != NULL) {
 
@@ -333,26 +443,25 @@ GDate *new_cdate;
         gtk_tree_path_free(path);
     }
 
-    /*check tasks */
+    return FALSE;
+}
 
-    if (appGUI->tsk->tasks_list_store != NULL) {
-        path = gtk_tree_path_new_first();
+/*------------------------------------------------------------------------------*/
 
-        while (gtk_tree_model_get_iter (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, path) == TRUE) {
-            gtk_tree_model_get (GTK_TREE_MODEL(appGUI->tsk->tasks_list_store), &iter, 
-                                COLUMN_DUE_DATE_JULIAN, &date, -1);
-
-            if (date == selected_julian) {
-                return TRUE;
-            }
-
-            gtk_tree_path_next(path);
-        }
-        gtk_tree_path_free(path);
+gboolean
+check_tasks_contacts(guint tc_day, guint tc_month, guint tc_year, GUI *appGUI) {
 
+    if (appGUI->calendar_only == TRUE || appGUI->all_pages_added == FALSE) {
+        return FALSE;
     }
 
-    return FALSE;
+    /* check contacts */
+    if (check_contacts (tc_day, tc_month, tc_year, appGUI) == TRUE) {
+        return TRUE;
+    }
+
+    /*check tasks */
+    return check_tasks (tc_day, tc_month, tc_year, appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -364,7 +473,9 @@ GtkTextChildAnchor *anchor;
 GtkWidget *table, *label;
 gchar *text;
 gchar tmpbuf[BUFFER_SIZE];
-gint ydays;
+gint ydays, edays;
+gboolean current_date;
+static guint cmonth;
 
     gui_clear_text_buffer (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
 
@@ -372,39 +483,34 @@ gint ydays;
 
     anchor = gtk_text_buffer_create_child_anchor (appGUI->cal->day_desc_text_buffer, &appGUI->cal->day_desc_iter);
 
-    table = gtk_table_new (3, 3+2, FALSE);
+    table = gtk_table_new (6, 3, FALSE);
     gtk_widget_show (table);
     gtk_table_set_row_spacings (GTK_TABLE (table), 4);
     gtk_table_set_col_spacings (GTK_TABLE (table), 8);
 
+    current_date = (dday == get_current_day()) && (dmonth == get_current_month()) && (dyear == get_current_year());
+
+    if (current_date) {
+        sprintf(tmpbuf, "<b>%s:</b>", _("Current time"));
+        label = gtk_label_new (tmpbuf);
+        gtk_widget_show (label);
+        gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+        gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+    }
+
     sprintf(tmpbuf, "<b>%s:</b>", _("Day number"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Week number"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
-                      (GtkAttachOptions) (GTK_FILL),
-                      (GtkAttachOptions) (0), 0, 0);
-    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
-    sprintf(tmpbuf, "<b>%s:</b>", _("Marked days"));
-    label = gtk_label_new (tmpbuf);
-    gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    sprintf(tmpbuf, "<b>%s:</b>", _("Weekend days"));
+    sprintf(tmpbuf, "<b>%s:</b>", _("Week number"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 3, 4,
@@ -413,7 +519,16 @@ gint ydays;
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
-    sprintf(tmpbuf, "<b>%s:</b>", _("Moon phase"));
+    sprintf(tmpbuf, "<b>%s:</b>", _("Marked days"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    sprintf(tmpbuf, "<b>%s:</b>", _("Weekend days"));
     label = gtk_label_new (tmpbuf);
     gtk_widget_show (label);
     gtk_table_attach (GTK_TABLE (table), label, 0, 1, 4, 5,
@@ -422,51 +537,70 @@ gint ydays;
     gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
+    sprintf(tmpbuf, "<b>%s:</b>", _("Moon phase"));
+    label = gtk_label_new (tmpbuf);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+    gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+
+    appGUI->cal->time_label = gtk_label_new (NULL);
+    if (current_date) {
+        time_handler (appGUI);
+        gtk_widget_show (appGUI->cal->time_label);
+    }
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->time_label, 1, 3, 0, 1,
+                      (GtkAttachOptions) (GTK_FILL),
+                      (GtkAttachOptions) (0), 0, 0);
+    gtk_misc_set_alignment (GTK_MISC (appGUI->cal->time_label), 0, 0.5);
+
     appGUI->cal->day_number_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->day_number_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_label, 1, 2, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_label, 1, 2, 1, 2,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_label), 0, 0.5);
 
     appGUI->cal->day_number_year_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->day_number_year_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_year_label, 2, 3, 0, 1,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->day_number_year_label, 2, 3, 1, 2,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->day_number_year_label), 0, 0.5);
 
     appGUI->cal->week_number_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->week_number_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->week_number_label, 1, 3, 2, 3,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->week_number_label, 1, 3, 3, 4,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->week_number_label), 0, 0.5);
 
     appGUI->cal->marked_days_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->marked_days_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->marked_days_label, 1, 3, 1, 2,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->marked_days_label, 1, 3, 2, 3,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->marked_days_label), 0, 0.5);
 
     appGUI->cal->weekend_days_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->weekend_days_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->weekend_days_label, 1, 3, 3, 4,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->weekend_days_label, 1, 3, 4, 5,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->weekend_days_label), 0, 0.5);
 
     appGUI->cal->moon_icon = gtk_image_new();
     gtk_widget_show (appGUI->cal->moon_icon);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_icon, 1, 2, 4, 5,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_icon, 1, 2, 5, 6,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_icon), 0, 0.5);
 
     appGUI->cal->moon_phase_label = gtk_label_new (NULL);
     gtk_widget_show (appGUI->cal->moon_phase_label);
-    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_phase_label, 2, 3, 4, 5,
+    gtk_table_attach (GTK_TABLE (table), appGUI->cal->moon_phase_label, 2, 3, 5, 6,
                       (GtkAttachOptions) (GTK_FILL),
                       (GtkAttachOptions) (0), 0, 0);
     gtk_misc_set_alignment (GTK_MISC (appGUI->cal->moon_phase_label), 0, 0.5);
@@ -474,10 +608,21 @@ gint ydays;
 
     sprintf(tmpbuf, "%d", ydays);
     gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_label), tmpbuf);
-    sprintf(tmpbuf, "(%d %s)", get_days_per_year(dyear)-ydays,
-        ngettext ("day till end of year", "days till end of year", get_days_per_year(dyear)-ydays));
+
+    edays = get_days_per_year(dyear)-ydays;
+    if (edays) {
+        sprintf(tmpbuf, "(%d %s)", edays,
+            ngettext ("day till end of year", "days till end of year", edays));
+    } else {
+        sprintf(tmpbuf, "(%s)", _("the last day of the year"));
+    }
     gtk_label_set_text (GTK_LABEL(appGUI->cal->day_number_year_label), tmpbuf);
-    sprintf(tmpbuf, "%d / %d", get_week_of_the_year (dday, dmonth, dyear), get_week_of_the_year(31, 12-1, dyear));
+
+    if (week_number (dyear, dmonth+1, dday) > weeks_in_year (dyear)) {
+        sprintf (tmpbuf, "1 / %d", weeks_in_year (dyear+1));
+    } else {
+        sprintf (tmpbuf, "%d / %d", week_number (dyear, dmonth+1, dday), weeks_in_year (dyear));
+    }
     gtk_label_set_text (GTK_LABEL(appGUI->cal->week_number_label), tmpbuf);
 
     set_moon_icon (calc_moon_phase(dyear, dmonth+1, dday), appGUI);
@@ -508,6 +653,10 @@ gint ydays;
 
     check_tasks_and_contacts(date_to_julian (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year), appGUI);
 
+    if (cmonth != dmonth) {
+        cmonth = dmonth;
+        update_aux_calendars (appGUI);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
@@ -549,6 +698,7 @@ day_notes_toggled_cb (GtkToggleToolButton *togglebutton, gpointer user_data) {
         gtk_text_view_set_editable(GTK_TEXT_VIEW(appGUI->cal->calendar_note_textview), FALSE);
         gtk_widget_hide(appGUI->cal->notes_vbox);
         gtk_widget_show(appGUI->cal->day_info_vbox);
+        gui_systray_tooltip_update(appGUI);
     } else {
         gtk_widget_show(appGUI->cal->notes_vbox);
         gtk_widget_hide(appGUI->cal->day_info_vbox);
@@ -656,6 +806,7 @@ GUI *appGUI;
                 enable_disable_note_buttons(appGUI);
                 calendar_update_note (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, NULL, appGUI);
                 mark_days_with_notes (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+                gui_systray_tooltip_update(appGUI);
             }
         }
     }
@@ -713,6 +864,7 @@ calendar_btn_prev_day (GUI *appGUI) {
             appGUI->cal->day = 31;
         }
     }
+
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -735,6 +887,7 @@ calendar_btn_next_day (GUI *appGUI) {
             appGUI->cal->day = 1;
         }
     }
+
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -765,6 +918,7 @@ calendar_btn_prev_week (GUI *appGUI) {
             appGUI->cal->day += get_number_of_days_in_month(appGUI->cal->month, appGUI->cal->year) - 7;
         }
     }
+    
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -787,6 +941,7 @@ calendar_btn_next_week (GUI *appGUI) {
             appGUI->cal->month = 0;
         }
     }
+
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -803,6 +958,7 @@ calendar_btn_prev_month (GUI *appGUI) {
         appGUI->cal->year--;
         appGUI->cal->month = 11;
     }
+ 
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -819,6 +975,7 @@ calendar_btn_next_month (GUI *appGUI) {
         appGUI->cal->year++;
         appGUI->cal->month = 0;
     }
+ 
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
 }
 
@@ -831,6 +988,7 @@ calendar_btn_prev_year (GUI *appGUI) {
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     if (appGUI->cal->year > JULIAN_GREGORIAN_YEAR) appGUI->cal->year--;
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+    update_aux_calendars (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -842,6 +1000,7 @@ calendar_btn_next_year (GUI *appGUI) {
                           &appGUI->cal->year, &appGUI->cal->month, &appGUI->cal->day);
     appGUI->cal->year++;
     calendar_update_date (appGUI->cal->day, appGUI->cal->month, appGUI->cal->year, appGUI);
+    update_aux_calendars (appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -967,9 +1126,11 @@ click_handler_cb (GtkWidget * widget, GdkEventButton * event, gpointer data) {
 
     GUI *appGUI = (GUI *)data;
 
-    if (event->type == GDK_BUTTON_PRESS && event->button == 3) {
+    if (event->type == GDK_BUTTON_PRESS && event->button == 3) {    /* RMB */
         gtk_menu_popup(GTK_MENU(appGUI->cal->month_selector_menu), NULL, NULL, NULL, NULL, event->button, event->time);
         return TRUE;
+    } else if (event->type == GDK_BUTTON_PRESS && event->button == 2) {     /* MMB */
+        calendar_update_date (appGUI->cal->day, get_current_month(), appGUI->cal->year, appGUI);
     }
     return FALSE;
 }
@@ -1073,7 +1234,17 @@ calendar_edit_note_cb (GtkToggleToolButton *toggle_tool_button, gpointer data) {
     day_notes_toggled_cb (toggle_tool_button, appGUI);
 }
 
-/*------------------------------------------------------------------------------*/
+/*------------------------------------------------------------------------------*/ 
+
+void
+aux_cal_expander_cb (GObject *object, GParamSpec *param_spec, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+    config.auxilary_calendars_state = gtk_expander_get_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander));
+    update_aux_calendars (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/ 
 
 void
 gui_create_calendar(GtkWidget *notebook, GUI *appGUI) {
@@ -1093,6 +1264,7 @@ GError          *error = NULL;
 GtkActionGroup  *action_group = NULL;
 GtkWidget       *i_scrolledwindow;
 GtkWidget       *note_scrolledwindow;
+GtkWidget       *calendars_table;
 
 gchar tmpbuf[BUFFER_SIZE];
 
@@ -1243,6 +1415,7 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
                       G_CALLBACK (calendar_day_selected_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->cal->calendar), "day-selected-double-click", 
                       G_CALLBACK (calendar_dc_day_selected_cb), appGUI);
+    gui_calendar_enable_cursor (GUI_CALENDAR (appGUI->cal->calendar), TRUE);
 
     gui_calendar_set_tc_mark_color (GUI_CALENDAR (appGUI->cal->calendar), config.mark_color);
     gui_calendar_set_selector_color (GUI_CALENDAR (appGUI->cal->calendar), config.selection_color);
@@ -1250,8 +1423,70 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
     gui_calendar_set_weekend_color(GUI_CALENDAR (appGUI->cal->calendar), config.weekend_color);
     gui_calendar_set_mark_symbol (GUI_CALENDAR (appGUI->cal->calendar), get_mark_symbol(config.mark_symbol));
 
+    /*-------------------------------------------------------------------------------------*/
+
     if (appGUI->calendar_only == FALSE) {
 
+        appGUI->cal->aux_cal_expander = gtk_expander_new (_("Previous and next month"));
+        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->aux_cal_expander, GTK_CAN_FOCUS);
+        gtk_box_pack_start (GTK_BOX (vbox2), appGUI->cal->aux_cal_expander, FALSE, FALSE, 0);
+
+        if (config.enable_auxilary_calendars == TRUE) {
+            gtk_widget_show (appGUI->cal->aux_cal_expander);
+        }
+
+        calendars_table = gtk_table_new (2, 2, FALSE);
+        gtk_widget_show (calendars_table);
+        gtk_container_add (GTK_CONTAINER (appGUI->cal->aux_cal_expander), calendars_table);
+        gtk_table_set_row_spacings (GTK_TABLE (calendars_table), 4);
+        gtk_table_set_col_spacings (GTK_TABLE (calendars_table), 4);
+
+        appGUI->cal->prev_month_label = gtk_label_new ("");
+        gtk_widget_show (appGUI->cal->prev_month_label);
+        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->prev_month_label, 0, 1, 0, 1,
+                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+
+        appGUI->cal->next_month_label = gtk_label_new ("");
+        gtk_widget_show (appGUI->cal->next_month_label);
+        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->next_month_label, 1, 2, 0, 1,
+                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
+                          (GtkAttachOptions) (0), 0, 0);
+
+        appGUI->cal->calendar_prev = gui_calendar_new ();
+        gtk_widget_show (appGUI->cal->calendar_prev);
+        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar_prev, GTK_CAN_FOCUS);
+        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->calendar_prev, 0, 1, 1, 2,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
+        gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_prev), 
+                                          (config.display_options & (GUI_CALENDAR_SHOW_DAY_NAMES | GUI_CALENDAR_WEEK_START_MONDAY)) | GUI_CALENDAR_NO_MONTH_CHANGE);
+        gui_calendar_enable_cursor (GUI_CALENDAR (appGUI->cal->calendar_prev), FALSE);
+        gui_calendar_set_tc_mark_color (GUI_CALENDAR (appGUI->cal->calendar_prev), config.mark_color);
+        gui_calendar_set_selector_color (GUI_CALENDAR (appGUI->cal->calendar_prev), config.selection_color);
+        gui_calendar_set_header_color(GUI_CALENDAR (appGUI->cal->calendar_prev), config.header_color);
+        gui_calendar_set_weekend_color(GUI_CALENDAR (appGUI->cal->calendar_prev), config.weekend_color);
+        gui_calendar_set_mark_symbol (GUI_CALENDAR (appGUI->cal->calendar_prev), get_mark_symbol(config.mark_symbol));
+
+        appGUI->cal->calendar_next = gui_calendar_new ();
+        gtk_widget_show (appGUI->cal->calendar_next);
+        GTK_WIDGET_UNSET_FLAGS(appGUI->cal->calendar_next, GTK_CAN_FOCUS);
+        gtk_table_attach (GTK_TABLE (calendars_table), appGUI->cal->calendar_next, 1, 2, 1, 2,
+                          (GtkAttachOptions) (GTK_FILL),
+                          (GtkAttachOptions) (GTK_FILL), 0, 0);
+        gui_calendar_set_display_options (GUI_CALENDAR (appGUI->cal->calendar_next), 
+                                          (config.display_options & (GUI_CALENDAR_SHOW_DAY_NAMES | GUI_CALENDAR_WEEK_START_MONDAY)) | GUI_CALENDAR_NO_MONTH_CHANGE);
+        gui_calendar_enable_cursor (GUI_CALENDAR (appGUI->cal->calendar_next), FALSE);
+        gui_calendar_set_tc_mark_color (GUI_CALENDAR (appGUI->cal->calendar_next), config.mark_color);
+        gui_calendar_set_selector_color (GUI_CALENDAR (appGUI->cal->calendar_next), config.selection_color);
+        gui_calendar_set_header_color(GUI_CALENDAR (appGUI->cal->calendar_next), config.header_color);
+        gui_calendar_set_weekend_color(GUI_CALENDAR (appGUI->cal->calendar_next), config.weekend_color);
+        gui_calendar_set_mark_symbol (GUI_CALENDAR (appGUI->cal->calendar_next), get_mark_symbol(config.mark_symbol));
+
+    /*-------------------------------------------------------------------------------------*/
+
+    /*if (appGUI->calendar_only == FALSE) {*/
+
     /*-------------------------------------------------------------------------------------*/
     /* notes */
 
@@ -1407,6 +1642,12 @@ guint n_t_entries = G_N_ELEMENTS (t_entries);
         gtk_widget_realize(GTK_WIDGET(appGUI->cal->calendar_note_textview));
         gtk_widget_grab_focus(GTK_WIDGET(appGUI->cal->calendar_note_textview));
     }
+
+    if (appGUI->calendar_only == FALSE) {
+        g_signal_connect (G_OBJECT(appGUI->cal->aux_cal_expander), "notify::expanded", 
+                          G_CALLBACK(aux_cal_expander_cb), appGUI);
+        gtk_expander_set_expanded (GTK_EXPANDER(appGUI->cal->aux_cal_expander), config.auxilary_calendars_state);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
