@@ -47,9 +47,12 @@ gchar *     get_mark_symbol                         (gint idx);
 gchar *     calendar_get_note_text                  (GUI *appGUI);
 void        calendar_create_color_selector_window   (gboolean window_pos, GUI *appGUI);
 void        calendar_create_popup_menu              (GtkWidget *menu, GUI *appGUI);
+gboolean    check_tasks                             (guint tc_day, guint tc_month, guint tc_year, GUI *appGUI);
+gboolean    check_contacts                          (guint tc_day, guint tc_month, guint tc_year, GUI *appGUI);
 gboolean    check_tasks_contacts                    (guint tc_day, guint tc_month, guint tc_year, GUI *appGUI);
 void        set_day_info                            (guint dday, guint dmonth, guint dyear, GUI *appGUI);
 void        calendar_refresh_marks                  (GUI *appGUI);
+void        update_aux_calendars                    (GUI *appGUI);
 
 void        calendar_btn_prev_day                   (GUI *appGUI);
 void        calendar_btn_next_day                   (GUI *appGUI);
