@@ -30,8 +30,8 @@
 #include "i18n.h"
 #include "calendar.h"
 #include "calendar_calc.h"
-#include "calendar_utils.h"
 #include "time_utils.h"
+#include "date_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 #include "gui_utils.h"
@@ -81,7 +81,6 @@ date_calculator_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer us
 void
 set_current_date (GtkWidget *year, GtkWidget *month, GtkWidget *day)
 {
-
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (year), get_current_year ());
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (month), get_current_month () + 1);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (day), get_current_day ());
@@ -92,7 +91,6 @@ set_current_date (GtkWidget *year, GtkWidget *month, GtkWidget *day)
 void
 set_current_time (GtkWidget *hour, GtkWidget *minute, GtkWidget *second)
 {
-
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (hour), get_current_hour ());
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (minute), get_current_minute ());
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (second), get_current_second ());
@@ -103,7 +101,6 @@ set_current_time (GtkWidget *hour, GtkWidget *minute, GtkWidget *second)
 void
 reset_current_time (GtkWidget *hour, GtkWidget *minute, GtkWidget *second)
 {
-
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (hour), 0);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (minute), 0);
     gtk_spin_button_set_value (GTK_SPIN_BUTTON (second), 0);
@@ -230,57 +227,50 @@ void
 set_result_cb (GtkWidget *widget, gpointer user_data)
 {
 GUI *appGUI = (GUI *)user_data;
-gint year, month, day, hour, minute, second;
-gint year2, month2, day2, hour2, minute2, second2;
-guint year3, month3, day3, week3, hour3, minute3, second3;
-/*long long unsigned int minute4, second4;*/
-guint64 minute4, second4;
-gint n;
+DATE date_from, date_to, date_diff;
+TIME time_from, time_to, time_diff;
+gint days, weeks;
+guint64 hours, minutes, seconds;
 gchar tmpbuf[BUFFER_SIZE];
 
-    year3 = month3 = day3 = week3 = hour3 = minute3 = second3 = 0;
-
-    year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    date_from.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_year));
-    month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    date_from.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_month)) - 1;
-    day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    date_from.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_day));
-
-    n = (gint)get_number_of_days_in_month (month, year);
-    if (day > n) {
-        day = n;
-    }
-
-    hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    time_from.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_hour));
-    minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    time_from.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_minute));
-    second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    time_from.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_start_second));
-
-    year2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_year));
-    month2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_month)) - 1;
-    day2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
-                (appGUI->cal->spinbutton_end_day));
-
-    n = (gint)get_number_of_days_in_month (month2, year2);
-    if (day2 > n) {
-        day2 = n;
+    days = (gint)get_number_of_days_in_month (date_from.month, date_from.year);
+    if (date_from.day > days) {
+        date_from.day = days;
     }
 
-    hour2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    date_to.year = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+                (appGUI->cal->spinbutton_end_year));
+    date_to.month = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+                (appGUI->cal->spinbutton_end_month)) - 1;
+    date_to.day = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+                (appGUI->cal->spinbutton_end_day));
+    time_to.hour = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_end_hour));
-    minute2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    time_to.minute = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_end_minute));
-    second2 = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
+    time_to.second = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON
                 (appGUI->cal->spinbutton_end_second));
+    days = (gint)get_number_of_days_in_month (date_to.month, date_to.year);
+    if (date_to.day > days) {
+        date_to.day = days;
+    }
 
-    n = (gint)(date_to_julian (day2, month2, year2) - date_to_julian (day, month, year));
+    days = calculate_date_time_diff (date_from, time_from, date_to, time_to,
+                                     &date_diff, &time_diff);
 
-    if (n < 0 || (n == 0 && hour*3600+minute*60+second > hour2*3600+minute2*60+second2)) {
+    if (days == -1) {
         sprintf (tmpbuf, "<big>%s</big>", _("Start date is after the end date!"));
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), "<big> </big>");
@@ -292,55 +282,16 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_2), FALSE);
         gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_3), FALSE);
     } else {
-
-        if (second > second2) {
-            minute2--;
-            second3 = 60;
-        }
-        second3 += second2 - second;
-
-        if (minute > minute2) {
-            hour2--;
-            minute3 = 60;
-        }
-        minute3 += minute2 - minute;
-
-        if (hour > hour2) {
-            day2--;
-            n--;
-            hour3 = 24;
-        }
-        hour3 += hour2 - hour;
-
-        if (day2 < day) {
-            if (month2 == 0) {
-                year2--;
-                month2 = 11;
-            } else {
-                month2--;
-            }
-            day2 += (gint)get_number_of_days_in_month (month2, year2);
-        }
-        day3 = day2 - day;
-
-        if (month > month2) {
-            year2--;
-            month3 = 11;
-        }
-        month3 += month2 - month;
-
-        year3 = year2 - year;
-
         sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
-            year3, ngettext ("year", "years", year3),
-            month3, ngettext ("month", "months", month3),
-            day3, ngettext ("day", "days", day3));
+            date_diff.year, ngettext ("year", "years", date_diff.year),
+            date_diff.month, ngettext ("month", "months", date_diff.month),
+            date_diff.day, ngettext ("day", "days", date_diff.day));
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1), tmpbuf);
 
         sprintf (tmpbuf, "<big>%d %s, %d %s, %d %s</big>",
-            hour3, ngettext ("hour", "hours", hour3),
-            minute3, ngettext ("minute", "minutes", minute3),
-            second3, ngettext ("second", "seconds", second3));
+            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
+            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
+            time_diff.second, ngettext ("second", "seconds", time_diff.second));
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_1_2), tmpbuf);
 
         sprintf (tmpbuf, "<small>\n<i>%s:</i></small>", _("Alternative time units"));
@@ -348,21 +299,22 @@ gchar tmpbuf[BUFFER_SIZE];
 
         sprintf (tmpbuf, "<small>(%s: %d %s, %d %s, %d %s, %d %s)</small>",
             _("or"),
-            n, ngettext ("day", "days", n),
-            hour3, ngettext ("hour", "hours", hour3),
-            minute3, ngettext ("minute", "minutes", minute3),
-            second3, ngettext ("second", "seconds", second3));
+            days, ngettext ("day", "days", days),
+            time_diff.hour, ngettext ("hour", "hours", time_diff.hour),
+            time_diff.minute, ngettext ("minute", "minutes", time_diff.minute),
+            time_diff.second, ngettext ("second", "seconds", time_diff.second));
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_2), tmpbuf);
 
-        second4 = (guint64)second3 + (guint64)minute3 * 60 + (guint64)hour3 * 3600 + (guint64)n * 24 * 3600;
-        minute4 = second4 / 60;
-        hour3 = minute4 / 60;
-        week3 = hour3 / (24 * 7);
-        sprintf (tmpbuf, "<small>%llu %s\n%llu %s (%s)\n%d %s (%s)\n%d %s (%s)</small>",
-            second4, ngettext ("second", "seconds", second4),
-            minute4, ngettext ("minute", "minutes", minute4), _("rounded down"),
-            hour3, ngettext ("hour", "hours", hour3), _("rounded down"),
-            week3, ngettext ("week", "weeks", week3), _("rounded down"));
+        seconds = (guint64)time_diff.second + (guint64)time_diff.minute * 60 +
+                  (guint64)time_diff.hour * 3600 + (guint64)days * 24 * 3600;
+        minutes = seconds / 60;
+        hours = minutes / 60;
+        weeks = (gint)(hours / (24 * 7));
+        sprintf (tmpbuf, "<small>%llu %s\n%llu %s (%s)\n%llu %s (%s)\n%d %s (%s)</small>",
+            seconds, ngettext ("second", "seconds", seconds),
+            minutes, ngettext ("minute", "minutes", minutes), _("rounded down"),
+            hours, ngettext ("hour", "hours", hours), _("rounded down"),
+            weeks, ngettext ("week", "weeks", weeks), _("rounded down"));
         gtk_label_set_markup (GTK_LABEL (appGUI->cal->label_result_3), tmpbuf);
 
         gtk_label_set_selectable (GTK_LABEL (appGUI->cal->label_result_1), TRUE);
