@@ -34,7 +34,8 @@
 #include "calendar.h"
 #include "calendar_notes.h"
 #include "calendar_fullyear.h"
-#include "calendar_utils.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "stock_icons.h"
 
 
