@@ -27,8 +27,9 @@
 
 #include "i18n.h"
 #include "calendar.h"
-#include "calendar_utils.h"
 #include "calendar_jumpto.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -145,8 +146,10 @@ jumpto_go_window_close_cb (GtkButton *button, gpointer user_data) {
     appGUI->cal->jmonth = atoi (gtk_entry_get_text(GTK_ENTRY(appGUI->cal->month_entry)));
     appGUI->cal->jyear = atoi (gtk_entry_get_text(GTK_ENTRY(appGUI->cal->year_entry)));
 
-    if (is_valid_date(appGUI->cal->jday, appGUI->cal->jmonth-1, appGUI->cal->jyear) == TRUE)
+    if (is_valid_date2(appGUI->cal->jday, appGUI->cal->jmonth-1, appGUI->cal->jyear) == TRUE) {
         jump_to_date (appGUI->cal->jday, appGUI->cal->jmonth-1, appGUI->cal->jyear, appGUI);
+        update_aux_calendars (appGUI);
+    }
 
     jumpto_window_close_cb (GTK_WIDGET(button), NULL, user_data);
 
