@@ -38,9 +38,11 @@
 #include "gui_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
+#include "contacts_birthdays.h"
 #include "contacts_import.h"
 #include "contacts_export.h"
-#include "calendar_utils.h"
+#include "time_utils.h"
+#include "date_utils.h"
 
 /*------------------------------------------------------------------------------*/
 
@@ -661,6 +663,15 @@ contacts_remove_item_cb (GtkWidget *widget, gpointer data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+contacts_birthdays_item_cb (GtkWidget *widget, gpointer data) {
+
+    GUI *appGUI = (GUI *)data;
+    contacts_create_birthdays_window (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
 void
 contacts_export_items_cb (GtkWidget *widget, gpointer data) {
 
@@ -761,8 +772,9 @@ const gchar *ui_info =
 "  <toolbar name=\"toolbar\">\n"
 "    <toolitem name=\"add\" action=\"add\" />\n"
 "    <toolitem name=\"delete\" action=\"delete\" />\n"
-"    <separator name=\"sep1\" />\n"
 "    <toolitem name=\"edit\" action=\"edit\" />\n"
+"    <separator name=\"sep1\" />\n"
+"    <toolitem name=\"birthdays\" action=\"birthdays\" />\n"
 "    <separator name=\"sep2\" />\n"
 "    <toolitem name=\"import\" action=\"import\" />\n"
 "    <toolitem name=\"export\" action=\"export\" />\n"
@@ -770,8 +782,9 @@ const gchar *ui_info =
 
 GtkActionEntry entries[] = {
     { "add", OSMO_STOCK_CONTACTS_ADD, _("New contact"), NULL, _("New contact"), NULL },
-    { "edit", OSMO_STOCK_CONTACTS_EDIT, _("Edit contact"), NULL, _("Edit contact"), NULL },
     { "delete", OSMO_STOCK_CONTACTS_REMOVE, _("Remove contact"), NULL, _("Remove contact"), NULL },
+    { "edit", OSMO_STOCK_CONTACTS_EDIT, _("Edit contact"), NULL, _("Edit contact"), NULL },
+    { "birthdays", OSMO_STOCK_CONTACTS_BIRTHDAYS, _("Show birthdays"), NULL, _("Show birthdays"), NULL },
     { "import", OSMO_STOCK_CONTACTS_IMPORT, _("Import contacts"), NULL, _("Import contacts"), NULL },
     { "export", OSMO_STOCK_CONTACTS_EXPORT, _("Export contacts"), NULL, _("Export contacts"), NULL },
 };
@@ -827,6 +840,8 @@ guint n_entries = G_N_ELEMENTS (entries);
                       G_CALLBACK(contacts_edit_item_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/delete")), "clicked", 
                       G_CALLBACK(contacts_remove_item_cb), appGUI);
+    g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/birthdays")), "clicked", 
+                      G_CALLBACK(contacts_birthdays_item_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/export")), "clicked", 
                       G_CALLBACK(contacts_export_items_cb), appGUI);
     g_signal_connect (G_OBJECT(gtk_ui_manager_get_widget (appGUI->cnt->contacts_uim_widget, "/toolbar/import")), "clicked", 
