@@ -30,7 +30,8 @@
 #include "gui_utils.h"
 #include "contacts.h"
 #include "contacts_export.h"
-#include "calendar_utils.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "stock_icons.h"
 #include "options_prefs.h"
 
@@ -63,6 +64,23 @@ const gchar *text;
 
 /*-------------------------------------------------------------------------------------*/
 
+void
+export_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gtk_window_get_size (GTK_WINDOW(appGUI->cnt->export_window),
+                        &config.contacts_export_win_w, &config.contacts_export_win_h);
+    gdk_window_get_root_origin (GDK_WINDOW(appGUI->cnt->export_window->window),
+                                &config.contacts_export_win_x, &config.contacts_export_win_y);
+
+    gtk_widget_destroy(appGUI->cnt->export_window);
+    appGUI->cnt->output_file_entry = NULL;
+    appGUI->cnt->export_button = NULL;
+}
+
+/*-------------------------------------------------------------------------------------*/
+
 void
 export_cb (GtkWidget *widget, gpointer data) {
 
@@ -84,26 +102,12 @@ gchar tmpbuf[BUFFER_SIZE];
                 ngettext ("contact exported", "contacts exported", n));
 
             gui_create_dialog(GTK_MESSAGE_INFO, tmpbuf, GTK_WINDOW(appGUI->cnt->export_window));
-            gtk_widget_destroy(appGUI->cnt->export_window);
-            appGUI->cnt->output_file_entry = NULL;
-            appGUI->cnt->export_button = NULL;
+            export_window_close_cb (widget, NULL, appGUI);
 
         }
     }
 }
 
-/*-------------------------------------------------------------------------------------*/
-
-void
-export_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-
-    GUI *appGUI = (GUI *)user_data;
-
-    gtk_widget_destroy(appGUI->cnt->export_window);
-    appGUI->cnt->output_file_entry = NULL;
-    appGUI->cnt->export_button = NULL;
-}
-
 /*------------------------------------------------------------------------------*/
 
 void
@@ -470,7 +474,7 @@ export_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
     switch(event->keyval) {
         case GDK_Escape:
-            gtk_widget_destroy(appGUI->cnt->export_window);
+            export_window_close_cb (widget, NULL, appGUI);
             return TRUE;
     }
 
@@ -576,7 +580,7 @@ GtkWidget *cancel_button;
 GtkWidget *select_all_button;
 GtkWidget *select_none_button;
 GtkWidget *invert_selection_button;
-gint win_xpos, win_ypos, i;
+gint i;
 gchar tmpbuf[BUFFER_SIZE];
 static MESSAGE msg_export_field[CONTACTS_NUM_COLUMNS];
 static MESSAGE msg_select[3]; /* select all, select none, select invert */
@@ -585,14 +589,19 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     gtk_window_set_title (GTK_WINDOW (appGUI->cnt->export_window), _("Export contacts"));
     gtk_container_set_border_width (GTK_CONTAINER (appGUI->cnt->export_window), 6);
 
-    gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->export_window), EXPORT_WINDOW_SIZE_X, EXPORT_WINDOW_SIZE_Y);
-    gtk_window_set_position(GTK_WINDOW(appGUI->cnt->export_window), GTK_WIN_POS_CENTER_ON_PARENT);
+    gtk_window_move (GTK_WINDOW (appGUI->cnt->export_window), 
+                     config.contacts_export_win_x, config.contacts_export_win_y);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->export_window), 
+                                 config.contacts_export_win_w, config.contacts_export_win_h);
+
     gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->export_window), GTK_WINDOW(appGUI->main_window));
     gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->export_window), TRUE);
 
-    g_signal_connect (G_OBJECT (appGUI->cnt->export_window), "key_press_event", G_CALLBACK (export_key_press_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->cnt->export_window), "key_press_event", 
+                      G_CALLBACK (export_key_press_cb), appGUI);
 
-    g_signal_connect (G_OBJECT (appGUI->cnt->export_window), "delete_event", G_CALLBACK(export_window_close_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->cnt->export_window), "delete_event", 
+                      G_CALLBACK(export_window_close_cb), appGUI);
 
     vbox1 = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (vbox1);
@@ -860,8 +869,6 @@ static MESSAGE msg_select[3]; /* select all, select none, select invert */
     g_signal_connect(appGUI->cnt->export_button, "clicked", G_CALLBACK(export_cb), appGUI);
     gtk_widget_set_sensitive(appGUI->cnt->export_button, FALSE);
 
-    gtk_window_get_position (GTK_WINDOW(appGUI->cnt->export_window), &win_xpos, &win_ypos);
-    gtk_window_move (GTK_WINDOW (appGUI->cnt->export_window), win_xpos-EXPORT_WINDOW_SIZE_X/2, win_ypos-10);
     gtk_widget_show(appGUI->cnt->export_window);
 
 }
