@@ -36,8 +36,9 @@
 #include "gui_utils.h"
 #include "calendar.h"
 #include "calendar_notes.h"
-#include "calendar_utils.h"
 #include "calendar_widget.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -142,6 +143,7 @@ const gchar *text;
     gtk_tree_model_filter_refilter(GTK_TREE_MODEL_FILTER(appGUI->cnt->contacts_filter));
 
     set_export_active(appGUI);
+    gui_systray_tooltip_update(appGUI);
 }
 
 /*------------------------------------------------------------------------------*/
@@ -177,6 +179,7 @@ gchar tmpbuf[BUFFER_SIZE];
                     contacts_select_first_position_in_list(appGUI);
                     g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
                     set_export_active(appGUI);
+                    gui_systray_tooltip_update(appGUI);
                 }
             }
 
@@ -194,8 +197,10 @@ contacts_add_edit_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer
 
     GUI *appGUI = (GUI *)user_data;
 
+    gtk_window_get_size (GTK_WINDOW(appGUI->cnt->contacts_add_window),
+                        &config.contacts_addedit_win_w, &config.contacts_addedit_win_h);
     gdk_window_get_root_origin (appGUI->cnt->contacts_add_window->window,
-                        &config.contacts_add_edit_window_x, &config.contacts_add_edit_window_y);
+                        &config.contacts_addedit_win_x, &config.contacts_addedit_win_y);
     gtk_widget_destroy(appGUI->cnt->contacts_add_window);
 }
 
@@ -534,10 +539,12 @@ gchar *contact_replace_tags[] = {
 
     appGUI->cnt->birthday_date = appGUI->cnt->nameday_date = 0;
 
-    gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->contacts_add_window), CONTACTS_ADD_EDIT_WINDOW_SIZE_X, CONTACTS_ADD_EDIT_WINDOW_SIZE_Y);
     gtk_window_set_transient_for(GTK_WINDOW(appGUI->cnt->contacts_add_window), GTK_WINDOW(appGUI->main_window));
     gtk_window_set_modal(GTK_WINDOW(appGUI->cnt->contacts_add_window), TRUE);
-    gtk_window_move (GTK_WINDOW (appGUI->cnt->contacts_add_window), config.contacts_add_edit_window_x, config.contacts_add_edit_window_y);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->cnt->contacts_add_window), 
+                                 config.contacts_addedit_win_w, config.contacts_addedit_win_h);
+    gtk_window_move (GTK_WINDOW (appGUI->cnt->contacts_add_window), 
+                     config.contacts_addedit_win_x, config.contacts_addedit_win_y);
 
     g_signal_connect (G_OBJECT (appGUI->cnt->contacts_add_window), "key_release_event",
                       G_CALLBACK (contacts_add_edit_key_release_cb), appGUI);
