@@ -37,6 +37,8 @@
 #include "calendar_widget.h"
 #include "calendar_jumpto.h"
 #include "calendar_calc.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "tasks.h"
 #include "tasks_items.h"
 #include "contacts.h"
@@ -52,9 +54,38 @@
 /*------------------------------------------------------------------------------*/
 
 void
-gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+gui_toggle_window_visibility (GUI *appGUI) {
 
-    GUI *appGUI = (GUI *)user_data;
+    if (appGUI->no_tray == FALSE) {
+
+        appGUI->window_visible = !appGUI->window_visible;
+
+        if (appGUI->window_visible == TRUE) {
+            gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+            gtk_window_move (GTK_WINDOW (appGUI->main_window), config.window_x, config.window_y);
+            gtk_widget_show (appGUI->main_window);
+        } else {
+            if (appGUI->calendar_only == FALSE) {
+                config.lastrun_date = get_julian_for_today();
+                config.lastrun_time = get_seconds_for_today();
+                write_notes (appGUI);
+                write_tasks_entries(appGUI);
+                write_contacts_entries(appGUI);
+                prefs_write_config ();
+            }
+            gtk_widget_hide (appGUI->main_window);
+        }
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_quit_osmo (GUI *appGUI) {
+
+    if (appGUI->osmo_trayicon != NULL) {
+        gtk_status_icon_set_visible(appGUI->osmo_trayicon, FALSE);
+    }
 
     if (appGUI->calendar_only == FALSE) {
         if (appGUI->current_tab == PAGE_CALENDAR || 
@@ -66,11 +97,11 @@ gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
         gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON(appGUI->cal->notes_button), FALSE);
 
-        gtk_window_get_size (GTK_WINDOW(widget),
+        gtk_window_get_size (GTK_WINDOW(appGUI->main_window),
                             &config.window_size_x, &config.window_size_y);
     }
 
-    gdk_window_get_root_origin (GDK_WINDOW(widget->window),
+    gdk_window_get_root_origin (GDK_WINDOW(appGUI->main_window->window),
                         &config.window_x, &config.window_y);
 
     pango_font_description_free(appGUI->fd_day_name);
@@ -79,6 +110,7 @@ gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
     if (appGUI->calendar_only == FALSE) {
         write_notes (appGUI);
+        free_notes_list(appGUI);
         write_tasks_entries(appGUI);
         write_contacts_entries(appGUI);
     }
@@ -91,6 +123,20 @@ gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
 /*------------------------------------------------------------------------------*/
 
+void
+gui_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (config.enable_systray == TRUE && appGUI->no_tray == FALSE && appGUI->calendar_only == FALSE) {
+        gui_toggle_window_visibility (appGUI);
+    } else {
+        gui_quit_osmo(appGUI);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
 gint 
 key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer data) {
 
@@ -153,6 +199,10 @@ gint page;
                 case GDK_d:
                     calendar_create_calc_window  (appGUI);
                     return TRUE;
+                case GDK_a:
+                    gtk_expander_set_expanded (GTK_EXPANDER (appGUI->cal->aux_cal_expander),
+                                               !gtk_expander_get_expanded (GTK_EXPANDER (appGUI->cal->aux_cal_expander)));
+                    return TRUE;
             }
 
         }
@@ -375,7 +425,7 @@ gint page;
 
         case GDK_q:
             if (event->state & GDK_CONTROL_MASK) {  /* CTRL + Q */
-                    gui_window_close_cb(appGUI->main_window, NULL, appGUI);
+                    gui_quit_osmo(appGUI);
             }
             return FALSE;
 
@@ -457,7 +507,215 @@ notebook_sw_cb (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gp
 
 /*------------------------------------------------------------------------------*/
 
-void gui_create_window(GUI *appGUI) {
+gboolean            
+main_window_resized_cb (GtkWidget *widget, GdkEventConfigure *event, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    if (appGUI->calendar_only == FALSE) {
+        if (appGUI->tsk->tasks_panel_status == FALSE) {
+            gtk_paned_set_position(GTK_PANED(appGUI->tsk->tasks_paned), 99999);
+        }
+
+        if (appGUI->cnt->contacts_panel_status == FALSE) {
+            gtk_paned_set_position(GTK_PANED(appGUI->cnt->contacts_paned), 99999);
+        }
+    }
+
+    return FALSE;
+}
+
+/*------------------------------------------------------------------------------*/
+
+void 
+trayicon_clicked_cb (GtkStatusIcon *status_icon, gpointer user_data) {
+    GUI *appGUI = (GUI *)user_data;
+    gui_toggle_window_visibility (appGUI);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void 
+trayicon_popup_cb (GtkStatusIcon *status_icon, guint button, guint activate_time, gpointer user_data) {
+
+    GUI *appGUI = (GUI *)user_data;
+
+    gtk_menu_popup(GTK_MENU(appGUI->trayicon_popup_menu), NULL, NULL, NULL, NULL, 
+                   button, activate_time);
+
+}
+
+void
+systray_popup_menu_quit_selected_cb (gpointer user_data) {
+    GUI *appGUI = (GUI *)user_data;
+    if (appGUI->window_visible == FALSE) {
+        gtk_widget_show (appGUI->main_window);
+        appGUI->window_visible = TRUE;
+    }
+    gui_quit_osmo(appGUI);
+}
+
+void
+systray_popup_menu_show_calendar_selected_cb (gpointer user_data) {
+    GUI *appGUI = (GUI *)user_data;
+    if (appGUI->window_visible == FALSE) {
+        gtk_widget_show (appGUI->main_window);
+        appGUI->window_visible = TRUE;
+    }
+    gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CALENDAR);
+}
+
+void
+systray_popup_menu_show_tasks_selected_cb (gpointer user_data) {
+    GUI *appGUI = (GUI *)user_data;
+    if (appGUI->window_visible == FALSE) {
+        gtk_widget_show (appGUI->main_window);
+        appGUI->window_visible = TRUE;
+    }
+    gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_TASKS);
+}
+
+void
+systray_popup_menu_show_contacts_selected_cb (gpointer user_data) {
+    GUI *appGUI = (GUI *)user_data;
+    if (appGUI->window_visible == FALSE) {
+        gtk_widget_show (appGUI->main_window);
+        appGUI->window_visible = TRUE;
+    }
+    gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_NORMAL);
+    gtk_notebook_set_current_page (GTK_NOTEBOOK (appGUI->notebook), PAGE_CONTACTS);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_systray_tooltip_update (GUI *appGUI) {
+
+gchar       desc[BUFFER_SIZE], tmpbuf[BUFFER_SIZE];
+gboolean    flag = FALSE;
+
+    sprintf(tmpbuf, "%s", julian_to_str(get_julian_for_today(), DATE_FULL));
+    desc[0] = '\0';
+    strcat(desc, tmpbuf);
+
+    if (check_contacts(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+        strcat(desc, "\n");
+        flag = TRUE;
+        sprintf(tmpbuf, "\n%s", _("Birthday found"));
+        strcat(desc, tmpbuf);
+    }
+
+    if (check_tasks(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+        if (flag == FALSE) {
+            strcat(desc, "\n");
+            flag = TRUE;
+        }
+        sprintf(tmpbuf, "\n%s", _("Task found"));
+        strcat(desc, tmpbuf);
+    }
+
+    if (check_note(get_current_day(), get_current_month()+1, get_current_year(), appGUI) == TRUE) {
+        if (flag == FALSE) {
+            strcat(desc, "\n");
+            flag = TRUE;
+        }
+        sprintf(tmpbuf, "\n%s", _("Day note available"));
+        strcat(desc, tmpbuf);
+    }
+
+    gtk_status_icon_set_tooltip (appGUI->osmo_trayicon, desc);
+}
+
+/*------------------------------------------------------------------------------*/
+
+void
+gui_systray_initialize (GUI *appGUI) {
+
+GtkWidget   *menu_entry;
+GtkWidget   *systray_menu_separator;
+
+    if (appGUI->calendar_only == TRUE) {
+        return;
+    }
+
+    appGUI->trayicon_popup_menu = gtk_menu_new();
+
+    menu_entry = gtk_menu_item_new_with_label(_("Show calendar"));
+    gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->trayicon_popup_menu), menu_entry);
+    g_signal_connect_swapped(G_OBJECT(menu_entry), "activate", 
+                             G_CALLBACK(systray_popup_menu_show_calendar_selected_cb), appGUI);
+    gtk_widget_show(menu_entry);
+
+    menu_entry = gtk_menu_item_new_with_label(_("Show tasks"));
+    gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->trayicon_popup_menu), menu_entry);
+    g_signal_connect_swapped(G_OBJECT(menu_entry), "activate", 
+                             G_CALLBACK(systray_popup_menu_show_tasks_selected_cb), appGUI);
+    gtk_widget_show(menu_entry);
+
+    menu_entry = gtk_menu_item_new_with_label(_("Show contacts"));
+    gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->trayicon_popup_menu), menu_entry);
+    g_signal_connect_swapped(G_OBJECT(menu_entry), "activate", 
+                             G_CALLBACK(systray_popup_menu_show_contacts_selected_cb), appGUI);
+    gtk_widget_show(menu_entry);
+
+    systray_menu_separator = gtk_separator_menu_item_new();
+    gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->trayicon_popup_menu), systray_menu_separator);
+    gtk_widget_show(systray_menu_separator);
+
+	menu_entry = gtk_image_menu_item_new_with_label (_("Quit"));
+    gtk_menu_shell_append(GTK_MENU_SHELL(appGUI->trayicon_popup_menu), menu_entry);
+    g_signal_connect_swapped(G_OBJECT(menu_entry), "activate", 
+                             G_CALLBACK(systray_popup_menu_quit_selected_cb), appGUI);
+	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_entry), 
+                                   gtk_image_new_from_stock(GTK_STOCK_QUIT, GTK_ICON_SIZE_MENU));
+    gtk_widget_show(menu_entry);
+
+    /* create tray icon */
+
+    appGUI->osmo_trayicon = gtk_status_icon_new_from_stock(OSMO_STOCK_SYSTRAY_NORMAL);
+    g_signal_connect(G_OBJECT(appGUI->osmo_trayicon), "activate", 
+                     G_CALLBACK(trayicon_clicked_cb), appGUI);
+    g_signal_connect(G_OBJECT(appGUI->osmo_trayicon), "popup-menu",
+                     G_CALLBACK(trayicon_popup_cb), appGUI);
+
+    if (check_contacts(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_BIRTHDAY);
+    }
+
+    if (check_tasks(get_current_day(), get_current_month(), get_current_year(), appGUI) == TRUE) {
+        gtk_status_icon_set_from_stock (appGUI->osmo_trayicon, OSMO_STOCK_SYSTRAY_TASK);
+    }
+
+    appGUI->window_visible = TRUE;
+    gtk_widget_show(appGUI->main_window);
+
+    gui_systray_tooltip_update (appGUI);
+
+    if (config.enable_systray == TRUE) {
+        gtk_status_icon_set_visible(appGUI->osmo_trayicon, TRUE);
+        while (g_main_context_iteration(NULL, FALSE));
+
+        if (gtk_status_icon_is_embedded(appGUI->osmo_trayicon) == FALSE) {
+            appGUI->no_tray = TRUE;
+            gtk_status_icon_set_visible(appGUI->osmo_trayicon, FALSE);
+        } else {
+            appGUI->no_tray = FALSE;
+            gtk_status_icon_set_visible(appGUI->osmo_trayicon, TRUE);
+            if (config.start_minimised_in_systray) {
+                gui_toggle_window_visibility (appGUI);
+            }
+        }
+    } else {
+        gtk_status_icon_set_visible(appGUI->osmo_trayicon, FALSE);
+    }
+}
+
+/*------------------------------------------------------------------------------*/
+
+void 
+gui_create_window (GUI *appGUI) {
 
 GdkPixbuf   *icon;
 gchar tmpbuf[BUFFER_SIZE];
@@ -491,6 +749,8 @@ gchar tmpbuf[BUFFER_SIZE];
                       G_CALLBACK(gui_window_close_cb), appGUI);
     g_signal_connect (G_OBJECT (appGUI->main_window), "key_press_event",
                       G_CALLBACK (key_press_cb), appGUI);
+    g_signal_connect (G_OBJECT (appGUI->main_window), "configure_event",
+                      G_CALLBACK (main_window_resized_cb), appGUI);
 
     osmo_register_stock_icons();
 
@@ -544,10 +804,16 @@ gchar tmpbuf[BUFFER_SIZE];
     gui_url_initialize(appGUI);
 
     gtk_notebook_set_current_page(GTK_NOTEBOOK(appGUI->notebook), appGUI->current_tab);
-    gtk_widget_show(appGUI->main_window);
 
     appGUI->all_pages_added = TRUE;
     set_today (TRUE, appGUI);
+
+    update_aux_calendars (appGUI);
+    gui_systray_initialize (appGUI);
+ 
+    if (appGUI->calendar_only == TRUE) {
+        gtk_widget_show (appGUI->main_window);
+    }
 }
 
 /*------------------------------------------------------------------------------*/
@@ -602,6 +868,7 @@ const gchar *calendar_keys_text[] = {
     "<d>",                      N_("date calculator"),
     "<g>",                      N_("jump to date"),
     "<f>",                      N_("show full-year calendar"),
+    "<a>",                      N_("toggle calendars for the previous and next month"),
     "<Delete>",                 N_("remove day note"),
     "<Esc>",                    N_("close day note panel")
 };
