@@ -24,43 +24,17 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <config.h>
 
 #include "gui.h"
 #include "calendar.h"
 #include "i18n.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "options_prefs.h"
 
-
-/*------------------------------------------------------------------------------*/
-
-#define RUN_FLAG_FILE "pid"
-
-gboolean
-check_if_app_is_running(void) {
-
-FILE *fhandle;
-
-    fhandle = fopen(prefs_get_config_filename (RUN_FLAG_FILE), "r");
-
-    if (fhandle == NULL) {
-
-        fhandle = fopen(prefs_get_config_filename (RUN_FLAG_FILE), "w");
-
-        if (fhandle == NULL) {
-            return TRUE;
-        } else {
-            fprintf(fhandle, "%d", getpid());
-            fclose (fhandle);
-            return FALSE;
-        }
-
-    } else {
-        fclose (fhandle);
-    }
-
-    return TRUE;
-}
+#define RUN_FLAG_FILE "lock"
 
 /*------------------------------------------------------------------------------*/
 
@@ -73,6 +47,9 @@ CONTACTS *cnt = NULL;
 OPTIONS *opt = NULL;
 GtkWidget *info_dialog;
 gchar tmpbuf[BUFFER_SIZE];
+gint response = -1;
+struct flock *s_lock = NULL;
+int fhandle;
 
     appGUI = g_new0 (GUI, 1);
     g_return_val_if_fail (appGUI != NULL, -1);
@@ -98,6 +75,7 @@ gchar tmpbuf[BUFFER_SIZE];
     appGUI->hand_cursor = NULL;
     appGUI->regular_cursor = NULL;
     appGUI->gui_url_tag = NULL;
+    appGUI->trayicon_popup_menu = NULL;
 
     appGUI->cal->prev_day = appGUI->cal->prev_month = appGUI->cal->prev_year = 0;
     appGUI->calendar_only = FALSE;
@@ -124,46 +102,81 @@ gchar tmpbuf[BUFFER_SIZE];
             fprintf(stderr, "%s: %s [%s]\n\n", _("usage"), argv[0], _("options"));
             fprintf(stderr, "%s:\n", _("options"));
             fprintf(stderr, "    -cal : %s\n", _("show small calendar window"));
-            exit (-1);
+            goto finish;
         }
     }
 
+    s_lock = g_new0 (struct flock, 1);
+	s_lock->l_type = F_WRLCK;
+	s_lock->l_whence = SEEK_SET;
+	s_lock->l_start = 0;
+	s_lock->l_len = 0;
+
     prefs_read_config ();
 
+    close(creat(prefs_get_config_filename (RUN_FLAG_FILE), S_IRUSR | S_IWUSR));     /* create lock file */
+
     gtk_init (&argc, &argv);
 
-    if(check_if_app_is_running() == FALSE) {
+    fhandle = open(prefs_get_config_filename (RUN_FLAG_FILE), O_RDWR);
 
-        gtk_set_locale();
-        bindtextdomain(PACKAGE, LOCALEDIR);
-        textdomain(PACKAGE);
+    if (fhandle) {
+		if (fcntl(fhandle, F_SETLK, s_lock) == -1) {
+            close (fhandle);
 
-        gui_create_window (appGUI);
+            sprintf(tmpbuf, "%s %s\n\n%s", 
+                    _("Another copy of OSMO is already running."), 
+                    _("Simultaneously use two or more copies of OSMO can be a cause of data loss."), 
+                    _("Do you really want to continue?"));
 
-        gtk_main ();
+            info_dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
+                                                  GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, tmpbuf);
 
-        prefs_write_config ();
-        unlink(prefs_get_config_filename (RUN_FLAG_FILE));
+            gtk_window_set_title(GTK_WINDOW(info_dialog), _("Warning"));
+            gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
+            gtk_widget_show (info_dialog);
 
-    } else {
+            response = gtk_dialog_run(GTK_DIALOG(info_dialog));
+            gtk_widget_destroy(info_dialog);
 
-        sprintf(tmpbuf, _("Another copy of OSMO is already running or it has been stopped uncleanly (in this case please remove '%s' file and try again)."), prefs_get_config_filename (RUN_FLAG_FILE));
-
-        info_dialog = gtk_message_dialog_new (GTK_WINDOW_TOPLEVEL, GTK_DIALOG_MODAL,
-                                              GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, tmpbuf);
-
-        gtk_window_set_title(GTK_WINDOW(info_dialog), _("Error"));
-        gtk_window_set_position(GTK_WINDOW(info_dialog), GTK_WIN_POS_CENTER);
-        gtk_widget_show (info_dialog);
-        gtk_dialog_run(GTK_DIALOG(info_dialog));
-        gtk_widget_destroy(info_dialog);
+            if (response == GTK_RESPONSE_NO || response == GTK_RESPONSE_DELETE_EVENT) {   
+                goto finish;
+            }
+        }
     }
 
+    if (appGUI->calendar_only != TRUE) {
+
+        /* setup timer at 1000ms (1s) interval */
+       	g_timeout_add (1000, (GtkFunction) time_handler, appGUI);
+
+    }
+
+    gtk_set_locale();
+    bindtextdomain(PACKAGE, LOCALEDIR);
+    textdomain(PACKAGE);
+
+    gui_create_window (appGUI);
+
+    gtk_main ();
+
+    config.lastrun_date = get_julian_for_today();
+    config.lastrun_time = get_seconds_for_today();
+    prefs_write_config ();
+
+    if (fhandle) {
+    	s_lock->l_type = F_UNLCK;
+    	fcntl(fhandle, F_SETLK, s_lock);
+        close (fhandle);
+    }
+
+finish:
     g_free(opt);
     g_free(cnt);
     g_free(tsk);
     g_free(cal);
     g_free(appGUI);
+    g_free(s_lock);
     return 0;
 }
 
