@@ -38,7 +38,8 @@
 #include "calendar.h"
 #include "calendar_widget.h"
 #include "calendar_notes.h"
-#include "calendar_utils.h"
+#include "time_utils.h"
+#include "date_utils.h"
 
 
 /*------------------------------------------------------------------------------*/
@@ -72,7 +73,7 @@ prefs_set_default_values (void) {
 gint i;
 
     /* general */
-    config.window_x = 180;
+    config.window_x = 680;
     config.window_y = 120;
     config.window_size_x = 540;
     config.window_size_y = 690;
@@ -82,6 +83,11 @@ gint i;
     config.default_stock_icons = FALSE;
     config.disable_underline_links = FALSE;
     config.date_format = DATE_YYYY_MM_DD;
+    config.time_format = TIME_24;
+    config.enable_systray = TRUE;
+    config.start_minimised_in_systray = FALSE;
+    config.lastrun_date = get_julian_for_today();
+    config.lastrun_time = get_seconds_for_today();
     strncpy(config.web_browser, "firefox %s", MAXHELPERCMD-1);
     strncpy(config.email_client, "claws-mail --compose %s", MAXHELPERCMD-1);
 
@@ -98,6 +104,8 @@ gint i;
     config.notes_in_info_panel = FALSE;
     config.cursor_type = CURSOR_FRAME;
     config.frame_cursor_thickness = 2;
+    config.enable_auxilary_calendars = FALSE;
+    config.auxilary_calendars_state = TRUE;
     strncpy(config.header_color, "#004048", MAXCOLORNAME-1);
     strncpy(config.weekend_color, "#880000", MAXCOLORNAME-1);
     strncpy(config.selection_color, "#526565", MAXCOLORNAME-1);
@@ -116,14 +124,16 @@ gint i;
     config.visible_due_date_column = TRUE;
     config.visible_priority_column = FALSE;
     config.visible_category_column = FALSE;
+    config.tasks_addedit_win_w = 370;
+    config.tasks_addedit_win_h = 440;
+    config.tasks_addedit_win_x = config.window_x-config.tasks_addedit_win_w/2;
+    config.tasks_addedit_win_y = config.window_y+20;
     strncpy(config.due_today_color, "#00981E", MAXCOLORNAME-1);
     strncpy(config.due_7days_color, "#0047B7", MAXCOLORNAME-1);
     strncpy(config.past_due_color, "#CB362C", MAXCOLORNAME-1);
     strncpy(config.task_info_font, "Sans 14", MAXFONTNAME-1);
 
     /* contacts */
-    config.contacts_add_edit_window_x = 100;
-    config.contacts_add_edit_window_y = 100;
     config.find_mode = CONTACTS_FF_FIRST_NAME;
     config.show_after_search = TRUE;
     config.hide_group_column = FALSE;
@@ -134,6 +144,18 @@ gint i;
     config.tags_font_size = 11;
     config.contacts_sorting_order = GTK_SORT_ASCENDING;
     config.contacts_sorting_mode = 0;
+    config.contacts_addedit_win_w = 500;
+    config.contacts_addedit_win_h = 600;
+    config.contacts_addedit_win_x = config.window_x-config.contacts_addedit_win_w/2;
+    config.contacts_addedit_win_y = config.window_y+20;
+    config.contacts_export_win_w = 500;
+    config.contacts_export_win_h = 400;
+    config.contacts_export_win_x = config.window_x-config.contacts_export_win_w/2;
+    config.contacts_export_win_y = config.window_y+20;
+    config.contacts_import_win_w = 650;
+    config.contacts_import_win_h = 450;
+    config.contacts_import_win_x = config.window_x-config.contacts_import_win_w/2;
+    config.contacts_import_win_y = config.window_y+20;
     strncpy(config.contact_tag_color, "#228B22", MAXCOLORNAME-1);
     strncpy(config.contact_link_color, "blue", MAXCOLORNAME-1);
 
@@ -264,6 +286,41 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "time_format"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.time_format);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "enable_systray"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.enable_systray);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "start_minimised_in_systray"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.start_minimised_in_systray);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "lastrun_date"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.lastrun_date);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(general_node->name, (const xmlChar *) "lastrun_time"))) {
+                            key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.lastrun_time);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(general_node->name, (const xmlChar *)"web_browser"))) {
                             key = xmlNodeListGetString(doc, general_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -376,6 +433,20 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "enable_auxilary_calendars"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.enable_auxilary_calendars);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(calendar_node->name, (const xmlChar *) "auxilary_calendars_state"))) {
+                            key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.auxilary_calendars_state);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(calendar_node->name, (const xmlChar *)"header_color"))) {
                             key = xmlNodeListGetString(doc, calendar_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -501,6 +572,34 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "tasks_addedit_win_x"))) {
+                            key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tasks_addedit_win_x);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "tasks_addedit_win_y"))) {
+                            key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tasks_addedit_win_y);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "tasks_addedit_win_w"))) {
+                            key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tasks_addedit_win_w);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(tasks_node->name, (const xmlChar *) "tasks_addedit_win_h"))) {
+                            key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.tasks_addedit_win_h);
+                            xmlFree(key);
+                        }
+
                         if ((!xmlStrcmp(tasks_node->name, (const xmlChar *)"due_today_color"))) {
                             key = xmlNodeListGetString(doc, tasks_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -542,20 +641,6 @@ xmlChar *key;
 
                     while (contacts_node != NULL) {
 
-                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "add_edit_window_x"))) {
-                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    sscanf((gchar *) key, "%d", &config.contacts_add_edit_window_x);
-                            xmlFree(key);
-                        }
-
-                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "add_edit_window_y"))) {
-                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
-                            if (key != NULL)
-                                    sscanf((gchar *) key, "%d", &config.contacts_add_edit_window_y);
-                            xmlFree(key);
-                        }
-
                         if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "find_mode"))) {
                             key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
                             if (key != NULL)
@@ -654,6 +739,90 @@ xmlChar *key;
                             xmlFree(key);
                         }
 
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_addedit_win_x"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_addedit_win_x);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_addedit_win_y"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_addedit_win_y);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_addedit_win_w"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_addedit_win_w);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_addedit_win_h"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_addedit_win_h);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_export_win_x"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_export_win_x);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_export_win_y"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_export_win_y);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_export_win_w"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_export_win_w);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_export_win_h"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_export_win_h);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_import_win_x"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_import_win_x);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_import_win_y"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_import_win_y);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_import_win_w"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_import_win_w);
+                            xmlFree(key);
+                        }
+
+                        if ((!xmlStrcmp(contacts_node->name, (const xmlChar *) "contacts_import_win_h"))) {
+                            key = xmlNodeListGetString(doc, contacts_node->xmlChildrenNode, 1);
+                            if (key != NULL)
+                                    sscanf((gchar *) key, "%d", &config.contacts_import_win_h);
+                            xmlFree(key);
+                        }
+
                         contacts_node = contacts_node->next;
                     }
                 }
@@ -711,6 +880,16 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "disable_underline_links", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.date_format);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "date_format", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.time_format);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "time_format", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.enable_systray);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "enable_systray", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.start_minimised_in_systray);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "start_minimised_in_systray", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.lastrun_date);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "lastrun_date", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.lastrun_time);
+    xmlNewTextChild(general_node, NULL, (const xmlChar *) "lastrun_time", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXHELPERCMD, "%s", config.web_browser);
     xmlNewTextChild(general_node, NULL, (const xmlChar *) "web_browser", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXHELPERCMD, "%s", config.email_client);
@@ -746,6 +925,10 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "cursor_type", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.frame_cursor_thickness);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "frame_cursor_thickness", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.enable_auxilary_calendars);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "enable_auxilary_calendars", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.auxilary_calendars_state);
+    xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "auxilary_calendars_state", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.header_color);
     xmlNewTextChild(calendar_node, NULL, (const xmlChar *) "header_color", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.weekend_color);
@@ -785,6 +968,14 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "visible_priority_column", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.visible_category_column);
     xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "visible_category_column", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tasks_addedit_win_x);
+    xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "tasks_addedit_win_x", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tasks_addedit_win_y);
+    xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "tasks_addedit_win_y", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tasks_addedit_win_w);
+    xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "tasks_addedit_win_w", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.tasks_addedit_win_h);
+    xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "tasks_addedit_win_h", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.due_today_color);
     xmlNewTextChild(tasks_node, NULL, (const xmlChar *) "due_today_color", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, MAXCOLORNAME, "%s", config.due_7days_color);
@@ -800,10 +991,6 @@ gchar tmpbuf[BUFFER_SIZE];
     contacts_node = xmlNewNode(NULL, (const xmlChar *) "contacts");
     xmlAddChild(node, contacts_node);
 
-    snprintf(tmpbuf, 32, "%d", config.contacts_add_edit_window_x);
-    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "add_edit_window_x", (xmlChar *) tmpbuf);
-    snprintf(tmpbuf, 32, "%d", config.contacts_add_edit_window_y);
-    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "add_edit_window_y", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.find_mode);
     xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "find_mode", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.show_after_search);
@@ -832,6 +1019,30 @@ gchar tmpbuf[BUFFER_SIZE];
     xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_sorting_order", (xmlChar *) tmpbuf);
     snprintf(tmpbuf, 32, "%d", config.contacts_sorting_mode);
     xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_sorting_mode", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_addedit_win_x);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_addedit_win_x", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_addedit_win_y);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_addedit_win_y", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_addedit_win_w);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_addedit_win_w", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_addedit_win_h);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_addedit_win_h", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_export_win_x);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_export_win_x", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_export_win_y);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_export_win_y", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_export_win_w);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_export_win_w", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_export_win_h);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_export_win_h", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_import_win_x);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_import_win_x", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_import_win_y);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_import_win_y", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_import_win_w);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_import_win_w", (xmlChar *) tmpbuf);
+    snprintf(tmpbuf, 32, "%d", config.contacts_import_win_h);
+    xmlNewTextChild(contacts_node, NULL, (const xmlChar *) "contacts_import_win_h", (xmlChar *) tmpbuf);
 
     /*---------------------------------------------------------------------------------------*/
 
