@@ -44,6 +44,11 @@ struct osmo_prefs
     gint        default_stock_icons;
     gint        disable_underline_links;
     gint        date_format;
+    gint        time_format;
+    gint        enable_systray;
+    gint        start_minimised_in_systray;
+    gint        lastrun_date;
+    gint        lastrun_time;
     gchar       web_browser[MAXHELPERCMD];
     gchar       email_client[MAXHELPERCMD];
 
@@ -60,6 +65,8 @@ struct osmo_prefs
     gint        notes_in_info_panel;
     gint        cursor_type;
     gint        frame_cursor_thickness;
+    gint        enable_auxilary_calendars;
+    gint        auxilary_calendars_state;
     gchar       header_color[MAXCOLORNAME];
     gchar       weekend_color[MAXCOLORNAME];
     gchar       selection_color[MAXCOLORNAME];
@@ -78,14 +85,16 @@ struct osmo_prefs
     gint        visible_due_date_column;
     gint        visible_priority_column;
     gint        visible_category_column;
+    gint        tasks_addedit_win_x;
+    gint        tasks_addedit_win_y;
+    gint        tasks_addedit_win_w;
+    gint        tasks_addedit_win_h;
     gchar       due_today_color[MAXCOLORNAME];
     gchar       due_7days_color[MAXCOLORNAME];
     gchar       past_due_color[MAXCOLORNAME];
     gchar       task_info_font[MAXFONTNAME];
 
     /* CONTACTS */
-    gint        contacts_add_edit_window_x;
-    gint        contacts_add_edit_window_y;
     gint        find_mode;
     gint        show_after_search;
     gint        hide_group_column;
@@ -96,6 +105,18 @@ struct osmo_prefs
     gint        tags_font_size;
     gint        contacts_sorting_order;
     gint        contacts_sorting_mode;
+    gint        contacts_addedit_win_x;
+    gint        contacts_addedit_win_y;
+    gint        contacts_addedit_win_w;
+    gint        contacts_addedit_win_h;
+    gint        contacts_export_win_x;
+    gint        contacts_export_win_y;
+    gint        contacts_export_win_w;
+    gint        contacts_export_win_h;
+    gint        contacts_import_win_x;
+    gint        contacts_import_win_y;
+    gint        contacts_import_win_w;
+    gint        contacts_import_win_h;
     gchar       contact_tag_color[MAXCOLORNAME];
     gchar       contact_link_color[MAXCOLORNAME];
     gint        export_format;
