@@ -60,13 +60,18 @@ GtkStockItem calendar_stock_items[] = {
     { (gchar*) OSMO_STOCK_BUTTON_TODAY,            (gchar*) N_("Today"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_BUTTON_YES,              (gchar*) N_("Yes"),                         0, 0, TRANSLATION_DOMAIN },
 
+    { (gchar*) OSMO_STOCK_SYSTRAY_BIRTHDAY,        (gchar*) N_("Birthday"),                    0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_NORMAL,          (gchar*) "Osmo",                            0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_SYSTRAY_TASK,            (gchar*) N_("Task"),                        0, 0, TRANSLATION_DOMAIN },
+
     { (gchar*) OSMO_STOCK_ABOUT,                   (gchar*) N_("About"),                       0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALENDAR,                (gchar*) N_("Calendar"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CALCULATOR,              (gchar*) N_("Calculator"),                  0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_ADD,            (gchar*) N_("Add contact"),                 0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_CONTACTS_BIRTHDAYS,      (gchar*) N_("Show birthdays"),              0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_EDIT,           (gchar*) N_("Edit contact"),                0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_CONTACTS_EXPORT,         (gchar*) N_("Export contacts"),              0, 0, TRANSLATION_DOMAIN },
-    { (gchar*) OSMO_STOCK_CONTACTS_IMPORT,         (gchar*) N_("Import contacts"),              0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_CONTACTS_EXPORT,         (gchar*) N_("Export contacts"),             0, 0, TRANSLATION_DOMAIN },
+    { (gchar*) OSMO_STOCK_CONTACTS_IMPORT,         (gchar*) N_("Import contacts"),             0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS_REMOVE,         (gchar*) N_("Remove contact"),              0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_CONTACTS,                (gchar*) N_("Contacts"),                    0, 0, TRANSLATION_DOMAIN },
     { (gchar*) OSMO_STOCK_EDIT_NOTE,               (gchar*) N_("Edit day note"),               0, 0, TRANSLATION_DOMAIN },
@@ -111,10 +116,15 @@ const guint8* calendar_stock_item_data[] = {
     (const guint8*) osmo_stock_button_today,
     (const guint8*) osmo_stock_button_yes,
 
+    (const guint8*) osmo_stock_systray_birthday,
+    (const guint8*) osmo_stock_systray_normal,
+    (const guint8*) osmo_stock_systray_task,
+
     (const guint8*) osmo_stock_about,
     (const guint8*) osmo_stock_calendar,
     (const guint8*) osmo_stock_calculator,
     (const guint8*) osmo_stock_contacts_add,
+    (const guint8*) osmo_stock_contacts_birthdays,
     (const guint8*) osmo_stock_contacts_edit,
     (const guint8*) osmo_stock_contacts_export,
     (const guint8*) osmo_stock_contacts_import,
