@@ -45,10 +45,15 @@
 #define     OSMO_STOCK_BUTTON_TODAY             "osmo-button-today"
 #define     OSMO_STOCK_BUTTON_YES               "osmo-button-yes"
 
+#define     OSMO_STOCK_SYSTRAY_BIRTHDAY         "osmo-systray-birthday"
+#define     OSMO_STOCK_SYSTRAY_NORMAL           "osmo-systray-normal"
+#define     OSMO_STOCK_SYSTRAY_TASK             "osmo-systray-task"
+
 #define     OSMO_STOCK_ABOUT                    "osmo-about"
 #define     OSMO_STOCK_CALENDAR                 "osmo-calendar"
 #define     OSMO_STOCK_CALCULATOR               "osmo-calculator"
 #define     OSMO_STOCK_CONTACTS_ADD             "osmo-contacts-add"
+#define     OSMO_STOCK_CONTACTS_BIRTHDAYS       "osmo-contacts-birthdays"
 #define     OSMO_STOCK_CONTACTS_EDIT            "osmo-contacts-edit"
 #define     OSMO_STOCK_CONTACTS_EXPORT          "osmo-contacts-export"
 #define     OSMO_STOCK_CONTACTS_IMPORT          "osmo-contacts-import"
