@@ -34,8 +34,9 @@
 #include "i18n.h"
 #include "tasks_items.h"
 #include "calendar.h"
-#include "calendar_utils.h"
 #include "calendar_widget.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "options_prefs.h"
 #include "stock_icons.h"
 
@@ -899,7 +900,6 @@ guint n_entries = G_N_ELEMENTS (entries);
     gtk_tree_view_append_column (GTK_TREE_VIEW(appGUI->tsk->tasks_list), appGUI->tsk->tasks_columns[COLUMN_DONE]);
 
     g_signal_connect (renderer, "toggled", G_CALLBACK (done_toggled), appGUI);
-                      /*GTK_TREE_MODEL(tasks_list_store));*/
 
     renderer = gtk_cell_renderer_text_new();
     appGUI->tsk->tasks_columns[COLUMN_DUE_DATE] = gtk_tree_view_column_new_with_attributes(_("Due date"),
