@@ -36,9 +36,10 @@
 #include "tasks.h"
 #include "tasks_items.h"
 #include "calendar.h"
-#include "calendar_utils.h"
 #include "calendar_notes.h"
 #include "calendar_widget.h"
+#include "time_utils.h"
+#include "date_utils.h"
 #include "stock_icons.h"
 
 /*------------------------------------------------------------------------------*/
@@ -94,6 +95,8 @@ guint32 fstartdate;
                          (gchar *) gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->summary_entry)),
                          gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE), appGUI);
 
+                        gui_systray_tooltip_update(appGUI);
+
     } else {
         add_item_to_list(FALSE, 
                          appGUI->tsk->tasks_due_julian_day,
@@ -102,6 +105,8 @@ guint32 fstartdate;
                          gtk_combo_box_get_active_text(GTK_COMBO_BOX(appGUI->tsk->category_combobox)),
                          (gchar *) gtk_entry_get_text(GTK_ENTRY(appGUI->tsk->summary_entry)),
                          gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_buffer), &iter_a, &iter_b, TRUE), appGUI);
+
+                        gui_systray_tooltip_update(appGUI);
     }
 
     gtk_widget_destroy(appGUI->tsk->tasks_add_window);
@@ -273,6 +278,11 @@ void
 tasks_add_edit_window_close_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 
     GUI *appGUI = (GUI *)user_data;
+
+    gtk_window_get_size (GTK_WINDOW(appGUI->tsk->tasks_add_window),
+                        &config.tasks_addedit_win_w, &config.tasks_addedit_win_h);
+    gdk_window_get_root_origin (GDK_WINDOW(appGUI->tsk->tasks_add_window->window),
+                             &config.tasks_addedit_win_x, &config.tasks_addedit_win_y);
     gtk_widget_destroy(appGUI->tsk->tasks_add_window);
 }
 
@@ -294,7 +304,7 @@ tasks_add_edit_key_press_cb (GtkWidget *widget, GdkEventKey *event, gpointer dat
     switch(event->keyval) {
 
         case GDK_Escape:
-            gtk_widget_destroy(appGUI->tsk->tasks_add_window);
+            tasks_add_edit_window_close_cb (appGUI->tsk->tasks_add_window, NULL, appGUI);
             return TRUE;
     }
 
@@ -342,6 +352,7 @@ gchar tmpbuf[BUFFER_SIZE];
                     tasks_select_first_position_in_list(appGUI);
                     update_n_items(appGUI);
                     g_signal_emit_by_name(G_OBJECT(appGUI->cal->calendar), "day-selected");
+                    gui_systray_tooltip_update(appGUI);
                 }
             }
 
@@ -366,7 +377,6 @@ GtkWidget *hseparator;
 GtkWidget *hbuttonbox;
 GtkWidget *table;
 GtkWidget *cancel_button;
-gint win_xpos, win_ypos;
 gchar tmpbuf[BUFFER_SIZE];
 
 
@@ -379,8 +389,11 @@ gchar tmpbuf[BUFFER_SIZE];
         gtk_window_set_title (GTK_WINDOW (appGUI->tsk->tasks_add_window), _("Add task"));
     }
 
-    gtk_window_set_default_size (GTK_WINDOW(appGUI->tsk->tasks_add_window), TASKS_ADD_EDIT_WINDOW_SIZE_X, TASKS_ADD_EDIT_WINDOW_SIZE_Y);
-    gtk_window_set_position(GTK_WINDOW(appGUI->tsk->tasks_add_window), GTK_WIN_POS_CENTER_ON_PARENT);
+    gtk_window_move (GTK_WINDOW (appGUI->tsk->tasks_add_window), 
+                     config.tasks_addedit_win_x, config.tasks_addedit_win_y);
+    gtk_window_set_default_size (GTK_WINDOW(appGUI->tsk->tasks_add_window), 
+                                 config.tasks_addedit_win_w, config.tasks_addedit_win_h);
+
     gtk_window_set_transient_for(GTK_WINDOW(appGUI->tsk->tasks_add_window), GTK_WINDOW(appGUI->main_window));
     gtk_window_set_modal(GTK_WINDOW(appGUI->tsk->tasks_add_window), TRUE);
 
@@ -562,8 +575,6 @@ gchar tmpbuf[BUFFER_SIZE];
 
     gtk_widget_set_sensitive(appGUI->tsk->tasks_ok_button, appGUI->tsk->tasks_accept_state);
 
-    gtk_window_get_position (GTK_WINDOW(appGUI->tsk->tasks_add_window), &win_xpos, &win_ypos);
-    gtk_window_move (GTK_WINDOW (appGUI->tsk->tasks_add_window), win_xpos-TASKS_ADD_EDIT_WINDOW_SIZE_X/2, win_ypos-10);
     gtk_widget_show(appGUI->tsk->tasks_add_window);
 }
 
