@@ -30,12 +30,28 @@ enum {
     TIME_TIMEZONE           /* last entry */
 };
 
-struct tm * get_tm_struct                   (void);
-gchar*      time_to_str                     (gint time_format);
-gboolean    is_valid_time                   (gint hour, gint minute, gint second, gboolean mode24);
-gint        get_current_hour                (void);
-gint        get_current_minute              (void);
-gint        get_current_second              (void);
+enum {
+    TIME_24 = 0,
+    TIME_12
+};
+
+typedef struct {
+    gint hour;
+    gint minute;
+    gint second;
+} TIME;
+
+gint            get_seconds_for_today   (void);
+gint            time_to_seconds         (TIME *time);
+TIME*           seconds_to_time         (gint seconds);
+struct tm *     get_tm_struct           (void);
+gchar*          time_to_str             (gint time_format);
+gboolean        is_valid_time           (TIME *time);
+gboolean        is_valid_time2          (gint hour, gint minute, gint second, gboolean mode24);
+gint            get_current_hour        (void);
+gint            get_current_minute      (void);
+gint            get_current_second      (void);
+gboolean        time_handler            (GUI *appGUI);
 
 #endif /* _TIME_UTILS_H */
 
